# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState, FeedTypes


class UpdateFeed(BaseModel):
    update_feed: Optional["UpdateFeedUpdateFeed"] = Field(alias="updateFeed")


class UpdateFeedUpdateFeed(BaseModel):
    id: str
    name: str
    state: EntityState
    type: FeedTypes


UpdateFeed.model_rebuild()
