# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryNotionPages(BaseModel):
    notion_pages: Optional["QueryNotionPagesNotionPages"] = Field(alias="notionPages")


class QueryNotionPagesNotionPages(BaseModel):
    results: Optional[List[str]]


QueryNotionPages.model_rebuild()
